@@ -175,9 +175,8 @@ class apic():
 			return data
 		else:
 			for device in data:
-				if device['deviceInfo']['serialNumber'] == serialNumber:
+				if serialNumber in device['deviceInfo']['serialNumber']:
 					ret = device
-
 			try:
 				return device
 			except:
@@ -214,7 +213,7 @@ class apic():
 				return data['response']
 			else:
 				for device in data['response']:
-					if device['serialNumber'] == serialNumber:
+					if serialNumber in device['serialNumber']:
 						return device
 
 
